<?php

function andrina_miscellaneous_blog_pattern() {
	wp_enqueue_style( 'andrina-miscellaneousblogwidget', ANDRINA_DIR_URI . "/includes/widgets/miscellaneous-blog-pattern/miscellaneous-blog-pattern.css", '', '', 'all' );
}

add_action( 'wp_enqueue_scripts', 'andrina_miscellaneous_blog_pattern' );

class miscellaneous_blog_pattern_widget extends WP_Widget {

	/**
	 * Sets up the widgets name etc
	 */
	public function __construct() {
		$widget_ops = array(
			'classname' => 'miscellaneous_blog_pattern_widget',
			'description' => 'This widget enables the miscellaneous type blog pattern on the home page.',
		);
		parent::__construct( 'miscellaneous_blog_pattern_widget', 'Miscellaneous Blog Pattern', $widget_ops );
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 */
	public function widget( $args, $instance ) {
//		 outputs the content of the widget
		echo $args['before_widget'];
		if ( !empty( $instance['title'] ) ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
		}

		$_max = $instance['numb_post'];
		$instance['category'];
		$count = 1;

		$paged = (get_query_var( 'paged' )) ? get_query_var( 'paged' ) : 1;
		// WP_Query arguments
		$blog_args = array(
			'post_type' => array( 'post' ),
			'post_status' => array( 'publish' ),
			'paged' => $paged,
			'cat' => $instance['category'],
			'posts_per_page' => $_max,
		);
		$query = new WP_Query( $blog_args );
		?>
		<div class="row">
			<?php
			if ( $query->have_posts() ) {
				while ( $query->have_posts() ) {
					$query->the_post();
					if ( $count == 1 || $count == 2 ) {
						?>

						<div class="col-md-6">
							<?php
							get_template_part( 'templates/home', 'content-two-columns-pattern' );
							?>
						</div>
						<?php
					} else {
						?>
						<div class="col-md-6">
							<?php
							get_template_part( 'templates/home', 'content-miscellaneous-pattern' );
							?>
						</div>
						<?php
					}
					$count++;
				}
			}
			?>
		</div>
		<?php
		wp_reset_query();

		echo $args['after_widget'];
	}

	/**
	 * Outputs the options form on admin
	 *
	 * @param array $instance The widget options
	 */
	public function form( $instance ) {
		// outputs the options form on admin
		$title = !empty( $instance['title'] ) ? $instance['title'] : __( 'Blog Posts', 'andrina-lite' );
		$numb_post = !empty( $instance['numb_post'] ) ? $instance['numb_post'] : 9;
		$category = !empty( $instance['category'] ) ? $instance['category'] : '';
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'andrina-lite'  ); ?></label> 
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'numb_post' ); ?>"><?php _e( 'Number Of Post:', 'andrina-lite'  ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'numb_post' ); ?>" name="<?php echo $this->get_field_name( 'numb_post' ); ?>" type="text" value="<?php echo esc_attr( $numb_post ); ?>">
		</p>
		<p>
			<label for="<?php echo $this->get_field_name( 'category' ); ?>"><?php _e( 'Categories:', 'andrina-lite' ); ?></label>
			<?php wp_dropdown_categories( array( 'name' => $this->get_field_name( 'category' ), 'selected' => $category ) ); ?>
		</p>
		<?php
	}

	/**
	 * Processing widget options on save
	 *
	 * @param array $new_instance The new options
	 * @param array $old_instance The previous options
	 */
	public function update( $new_instance, $old_instance ) {
		// processes widget options to be saved
		$instance = array();
		$instance['title'] = (!empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['numb_post'] = (!empty( $new_instance['numb_post'] ) ) ? strip_tags( $new_instance['numb_post'] ) : '9';
		$instance['category'] = (!empty( $new_instance['category'] ) ) ? strip_tags( $new_instance['category'] ) : '';
		return $instance;
	}

}

add_action( 'widgets_init', function() {
	register_widget( 'miscellaneous_blog_pattern_widget' );
} );
