<?php

function andrina_recent_post_css() {
    wp_enqueue_style('andrina-recentpostwidget', ANDRINA_DIR_URI . "includes/widgets/recent-post-widget/css/recent-post-widget.css", '', '', 'all');
}

add_action('wp_enqueue_scripts', 'andrina_recent_post_css');

class Andrina_Recent_Posts_Widget_With_Thumbnails extends WP_Widget {

    /**
     * Sets up the widgets name etc
     */
    public function __construct() {
        $widget_ops = array(
            'classname' => 'recent_post_widget',
            'description' => __('Recent Post With Their Feature Image','andrina-lite'),
        );
        parent::__construct('recent_post_widget', __('Recent Post With Thumbnail','andrina-lite'), $widget_ops);
    }

    /**
     * Outputs the content of the widget
     *
     * @param array $args
     * @param array $instance
     */
    public function widget($args, $instance) {
        echo $args['before_widget'];
        if (!empty($instance['title'])) {
            echo $args['before_title'] . apply_filters('widget_title', $instance['title']) . $args['after_title'];
        }
        $_max = $instance['numb_post'];
        $_max = $_max-1;
        $query_args = array(
            'posts_per_page' => $_max,
            'no_found_rows' => true,
            'post_status' => 'publish',
        );
        $r = new WP_Query(apply_filters('rpwwt_widget_posts_args', $query_args));
        if ($r->have_posts()) :
            // translate repeately used texts once (for more performance)
            $this->in_categories_text = _x('In', 'In {categories}', 'andrina-lite');
            $text = ', ';
            $this->comma_text = $text;
            $text = 'By %s';
            $this->author_text = $text;
            ?>
            <ul class="recent_post_wrapper">
                <?php
                while ($r->have_posts()) : $r->the_post();
//                    if (has_post_thumbnail()) {
                    ?>
                    <li class="recent_post_listing">
                        <div class="recent_post_img">
                            <?php
                            if (has_post_thumbnail()) {
                                the_post_thumbnail(95,70);
                            } else {
                                ?>
                                <img src="<?php echo get_template_directory_uri() . '/includes/widgets/recent-post-widget/images/post-image.jpg'?>" />
                            <?php }
                            ?> 
                        </div>
                        <?php
                        $is_thumb = true;
                        $trimtitle = $this->andrina_get_the_trimmed_post_title(100);
                        ?>
                        <div class="recent_post_meta">
                            <a class="recent_post_title" href="<?php the_permalink() ?>" rel="bookmark" title="<?php
                            _e('Permanent Link to ', 'andrina-lite');
                            the_title_attribute();
                            ?>"><?php echo $trimtitle; ?></a>
                            <i class="recent_post_date"><?php the_time(get_option('date_format')); ?></i>
                        </div>
                        <div class="clear"></div>
                        <?php
//                               andrina-lite_custom_excerpt(10);
                        ?>
                    </li>
                    <?php
//                    }
                endwhile;
                ?>
            </ul>
            <?php
            // Reset the global $the_post as this query will have stomped on it
            wp_reset_postdata();
        endif;
        echo $args['after_widget'];
    }

    /**
     * Outputs the options form on admin
     *
     * @param array $instance The widget options
     */
    public function form($instance) {
        // outputs the options form on admin
        $title = !empty($instance['title']) ? $instance['title'] : __('Recent Post', 'andrina-lite');
        $numb_post = !empty($instance['numb_post']) ? $instance['numb_post'] : 5;
        ?>
        <p>
            <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', 'andrina-lite' ); ?></label> 
            <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>">
            <label for="<?php echo $this->get_field_id('numb_post'); ?>"><?php _e('Number Of Post:', 'andrina-lite' ); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('numb_post'); ?>" name="<?php echo $this->get_field_name('numb_post'); ?>" type="text" value="<?php echo esc_attr($numb_post); ?>">
        </p>
        <?php
    }

    /**
     * Processing widget options on save
     *
     * @param array $new_instance The new options
     * @param array $old_instance The previous options
     */
    public function update($new_instance, $old_instance) {
        // processes widget options to be saved
        $instance = array();
        $instance['title'] = (!empty($new_instance['title']) ) ? strip_tags($new_instance['title']) : __('Recent Post', 'andrina-lite');
        $instance['numb_post'] = (!empty($new_instance['numb_post']) ) ? strip_tags($new_instance['numb_post']) : '5';
        return $instance;
    }

    private function andrina_get_the_trimmed_post_title($len = 1000, $more = '&hellip;') {
        // get current post's post_title
        $post_title = get_the_title();
        // if post_title is longer than desired
        if (mb_strlen($post_title) > $len) {
            // get post_title in desired length
            $post_title = mb_substr($post_title, 0, $len);
            // append ellipses
            $post_title .= $more;
        }
        return $post_title;
    }
}

/**
 * Register widget on init
 *
 * @since 1.0
 */
function andrina_register_recent_posts_widget_with_thumbnails() {
    register_widget('Andrina_Recent_Posts_Widget_With_Thumbnails');
}

add_action('widgets_init', 'andrina_register_recent_posts_widget_with_thumbnails', 1);
?>